from django.apps import AppConfig


class ActivitylibraryConfig(AppConfig):
    name = 'GymBuddyApp.activityLibrary'
